pub struct GoogleCloudVideointelligenceV1_TextDetectionConfig {
pub language_hints: Option<Vec<String>>,
pub model: Option<String>,
}Expand description
Config for TEXT_DETECTION.
This type is not used in any activity, and only used as part of another schema.
Fields
language_hints: Option<Vec<String>>Language hint can be specified if the language to be detected is known a priori. It can increase the accuracy of the detection. Language hint must be language code in BCP-47 format. Automatic language detection is performed if no hint is provided.
model: Option<String>Model to use for text detection. Supported values: “builtin/stable” (the default if unset) and “builtin/latest”.