pub struct GoogleLongrunning_ListOperationsResponse {
pub next_page_token: Option<String>,
pub operations: Option<Vec<GoogleLongrunning_Operation>>,
}Expand description
The response message for Operations.ListOperations.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations operations list projects (response)
Fields
next_page_token: Option<String>The standard List next-page token.
operations: Option<Vec<GoogleLongrunning_Operation>>A list of operations that matches the specified filter in the request.